From f0772cf415f090a873c7104bf78a4e885e94e446 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Emilio=20A=2E=20S=C3=A1nchez=20L=C3=B3pez?=
 <esanchez@yaco.es>
Date: Tue, 1 Feb 2011 15:59:15 +0000
Subject: [PATCH] Retrieve the person from the legacy tables of non IESG
 logins. Fixes #576  - Legacy-Id: 2782

---
 ietf/ietfauth/models.py | 11 ++++++++++-
 1 file changed, 10 insertions(+), 1 deletion(-)

diff --git a/ietf/ietfauth/models.py b/ietf/ietfauth/models.py
index 680b540ea..92fd40993 100644
--- a/ietf/ietfauth/models.py
+++ b/ietf/ietfauth/models.py
@@ -43,7 +43,16 @@ def find_person(username):
         return person
     except IESGLogin.DoesNotExist, PersonOrOrgInfo.DoesNotExist:
         pass
-    # TODO: try LegacyWgPassword next
+    # try LegacyWgPassword next
+    try:
+        return LegacyWgPassword.objects.get(login_name=username).person
+    except LegacyWgPassword.DoesNotExist, PersonOrOrgInfo.DoesNotExist:
+        pass
+    # try LegacyLiaisonUser next
+    try:
+        return LegacyLiaisonUser.objects.get(login_name=username).person
+    except LegacyLiaisonUser.DoesNotExist, PersonOrOrgInfo.DoesNotExist:
+        pass
     return None
 
 class IetfUserProfile(models.Model):